@@ -1,37 +1,23 @@
 /*
-*   Copyright (C) 2008 Nicola Gigante <nicola.gigante@gmail.com>
-*   Copyright (C) 2014,2016 René Bertin <rjvbertin@gmail.com>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU Lesser General Public License as published by
-*   the Free Software Foundation; either version 2.1 of the License, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU General Public License for more details.
-*
-*   You should have received a copy of the GNU Lesser General Public License
-*   along with this program; if not, write to the
-*   Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .
+    SPDX-FileCopyrightText: 2008 Nicola Gigante <nicola.gigante@gmail.com>
+    SPDX-FileCopyrightText: 2014, 2016 René Bertin <rjvbertin@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "AuthServicesBackend.h"
 
 #include <qplugin.h>
 
-#include <QLoggingCategory>
 #include <QDebug>
+#include <QLoggingCategory>
 
 Q_DECLARE_LOGGING_CATEGORY(KAUTH_OSX)
 // logging category for this backend, default: log stuff >= warning
-Q_LOGGING_CATEGORY(KAUTH_OSX, "kf5.kauth.apple", QtWarningMsg)
+Q_LOGGING_CATEGORY(KAUTH_OSX, "kf.auth.apple", QtWarningMsg)
 
 namespace KAuth
 {
-
 static AuthorizationRef s_authRef = NULL;
 
 AuthorizationRef authRef()
@@ -71,10 +57,7 @@ static OSStatus GetActionRights(const QString &action, AuthorizationFlags flags,
     rights.count = 1;
     rights.items = &item;
 
-    OSStatus result = AuthorizationCopyRights(auth,
-                                              &rights,
-                                              kAuthorizationEmptyEnvironment,
-                                              flags, NULL);
+    OSStatus result = AuthorizationCopyRights(auth, &rights, kAuthorizationEmptyEnvironment, flags, NULL);
     return result;
 }
 
@@ -82,7 +65,7 @@ static OSStatus GetActionRights(const QString &action, AuthorizationFlags flags,
 AuthServicesBackend::AuthServicesBackend()
     : AuthBackend()
 {
-    setCapabilities(AuthorizeFromClientCapability | CheckActionExistenceCapability);
+    setCapabilities(AuthorizeFromClientCapability);
 }
 
 AuthServicesBackend::~AuthServicesBackend()
@@ -105,30 +88,30 @@ Action::AuthStatus AuthServicesBackend::authorizeAction(const QString &action)
     OSStatus result = GetActionRights(action, kAuthorizationFlagExtendRights | kAuthorizationFlagInteractionAllowed, authRef());
     qCDebug(KAUTH_OSX) << "AuthServicesBackend::authorizeAction(" << action << ") AuthorizationCopyRights returned" << result;
     switch (result) {
-        case errAuthorizationSuccess:
-            retval = Action::AuthorizedStatus;
-            break;
-        case errAuthorizationCanceled:
-            retval = Action::UserCancelledStatus;
-            break;
-        case errAuthorizationInteractionNotAllowed:
-        case errAuthorizationDenied:
-            retval = Action::DeniedStatus;
-            break;
-        case errAuthorizationInternal:
-            // does this make sense?
-            retval = Action::AuthRequiredStatus;
-            break;
-        case errAuthorizationExternalizeNotAllowed:
-        case errAuthorizationInternalizeNotAllowed:
-        case errAuthorizationToolExecuteFailure:
-        case errAuthorizationToolEnvironmentError:
-        case errAuthorizationBadAddress:
-            retval = Action::ErrorStatus;
-            break;
-        default:
-            retval = Action::InvalidStatus;
-            break;
+    case errAuthorizationSuccess:
+        retval = Action::AuthorizedStatus;
+        break;
+    case errAuthorizationCanceled:
+        retval = Action::UserCancelledStatus;
+        break;
+    case errAuthorizationInteractionNotAllowed:
+    case errAuthorizationDenied:
+        retval = Action::DeniedStatus;
+        break;
+    case errAuthorizationInternal:
+        // does this make sense?
+        retval = Action::AuthRequiredStatus;
+        break;
+    case errAuthorizationExternalizeNotAllowed:
+    case errAuthorizationInternalizeNotAllowed:
+    case errAuthorizationToolExecuteFailure:
+    case errAuthorizationToolEnvironmentError:
+    case errAuthorizationBadAddress:
+        retval = Action::ErrorStatus;
+        break;
+    default:
+        retval = Action::InvalidStatus;
+        break;
     }
     return retval;
 }
@@ -140,18 +123,18 @@ Action::AuthStatus AuthServicesBackend::actionStatus(const QString &action)
     qCDebug(KAUTH_OSX) << "AuthServicesBackend::actionStatus(" << action << ") AuthorizationCopyRights returned" << result;
     // this function has a simpler return code parser:
     switch (result) {
-        case errAuthorizationSuccess:
-            retval = Action::AuthorizedStatus;
-            break;
-        case errAuthorizationCanceled:
-            retval = Action::UserCancelledStatus;
-            break;
-        case errAuthorizationInteractionNotAllowed:
-            retval = Action::AuthRequiredStatus;
-            break;
-        default:
-            retval = Action::DeniedStatus;
-            break;
+    case errAuthorizationSuccess:
+        retval = Action::AuthorizedStatus;
+        break;
+    case errAuthorizationCanceled:
+        retval = Action::UserCancelledStatus;
+        break;
+    case errAuthorizationInteractionNotAllowed:
+        retval = Action::AuthRequiredStatus;
+        break;
+    default:
+        retval = Action::DeniedStatus;
+        break;
     }
     return retval;
 }
@@ -179,8 +162,7 @@ bool AuthServicesBackend::isCallerAuthorized(const QString &action, const QByteA
         return false;
     }
 
-    OSStatus result = GetActionRights( action, kAuthorizationFlagExtendRights | kAuthorizationFlagInteractionAllowed,
-                      auth);
+    OSStatus result = GetActionRights(action, kAuthorizationFlagExtendRights | kAuthorizationFlagInteractionAllowed, auth);
 
     AuthorizationFree(auth, kAuthorizationFlagDefaults);
     qCDebug(KAUTH_OSX) << "AuthServicesBackend::isCallerAuthorized(" << action << "," << callerID.constData() << ") AuthorizationCopyRights returned" << result;
@@ -188,12 +170,6 @@ bool AuthServicesBackend::isCallerAuthorized(const QString &action, const QByteA
     return result == errAuthorizationSuccess;
 }
 
-// OS X doesn't distinguish between "action doesn't exist" and "action not allowed". So the
-// best thing we can do is return true and hope that the action will be created if it didn't exist...
-bool AuthServicesBackend::actionExists(const QString &)
-{
-    return true;
-}
-
 }; // namespace KAuth
 
+#include "moc_AuthServicesBackend.cpp"
